@@ -1,5 +1,4 @@
-`sfts` <-
-function (data, period = frequency(data), start = tsp(data)[1], 
+`sfts` <- function (data, period = frequency(data), start = tsp(data)[1], 
     frequency = 1, xname, yname) 
 {
     if (class(data) != "ts") {
@@ -18,19 +17,16 @@ function (data, period = frequency(data), start = tsp(data)[1],
         if (max(abs(ytimes - floor(ytimes))) < 1e-09) 
             ylab <- paste(ytimes)
         else if (frequency == 4) 
-            ylab <- paste(floor(ytimes), "-Q", cycle(ytimes), 
-                sep = "")
+            ylab <- paste(floor(ytimes), "-Q", cycle(ytimes), sep = "")
         else if (frequency == 12) {
             Mth <- month.abb[cycle(ytimes)]
             ylab <- paste(floor(ytimes), "-", Mth, sep = "")
         }
         else if (frequency == 7) {
-            Day <- c("Sun", "Mon", "Tue", "Wed", "Thu", "Fri", 
-                "Sat")[cycle(ytimes)]
+            Day <- c("Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat")[cycle(ytimes)]
             ylab <- paste(floor(ytimes), "-", Day, sep = "")
         }
-        else ylab <- paste(floor(ytimes), "-", cycle(ytimes), 
-            sep = "")
+        else ylab <- paste(floor(ytimes), "-", cycle(ytimes), sep = "")
         colnames(y) <- ylab
         rownames(y) <- x
         return(structure(list(x = x, y = y, time = ytimes, xname = xname, 
